asr.chc
=======

.. automodule:: asr.chc

   
   
   .. rubric:: Functions

   
   .. autofunction:: append_references
   .. autofunction:: calculate_intermediates
   .. autofunction:: chcut_plot
   .. autofunction:: convex_hull
   .. autofunction:: convex_hull_planes
   .. autofunction:: filrefs
   .. autofunction:: get_coords
   .. autofunction:: get_hof
   .. autofunction:: gscheck
   .. autofunction:: is_collinear
   .. autofunction:: is_independent
   .. autofunction:: mgs
   .. autofunction:: mgsls
   .. autofunction:: mu_adjustment
   .. autofunction:: orthogonalize
   .. autofunction:: projuv
   .. autofunction:: read_structure
   .. autofunction:: refs2ims
   .. autofunction:: results2ref
   .. autofunction:: row2ref
   .. autofunction:: tuplespermuted
   .. autofunction:: webpanel
   
   

   
   
   .. rubric:: Classes

   
   .. autoclass:: ConvexHullReference
      :members:
   .. autoclass:: Hyperplane
      :members:
   .. autoclass:: Intermediate
      :members:
   .. autoclass:: LeanIntermediate
      :members:
   .. autoclass:: Line
      :members:
   .. autoclass:: Reference
      :members:
   .. autoclass:: Result
      :members:
   
   

   
   
   .. rubric:: Exceptions

   
   .. autoexception:: CHCError
   
   